# Maintainers and contributors

## Maintainers

| Name | Github ID | Date |
|:-----------:|:-----:|:-----:|
| Xiyuan Wang| [@wangxiyuan](https://github.com/wangxiyuan) | 2025/01 |
| Yikun Jiang| [@Yikun](https://github.com/Yikun) | 2025/02 |
| Yi Gan| [@ganyi1996ppo](https://github.com/ganyi1996ppo) | 2025/02 |
| Shoujian Zheng| [@jianzs](https://github.com/jianzs) | 2025/06 |
| Wengang Chen | [@ApsarasX](https://github.com/ApsarasX) | 2025/08 |
| Mengqing Cao | [@MengqingCao](https://github.com/MengqingCao) | 2025/08 |
| Peng Yu| [@paulyu12](https://github.com/paulyu12) | 2025/10 |
| Yizhou Liu| [@yiz-liu](https://github.com/yiz-liu) | 2025/10 |
| Jinqian Wei | [@weijinqian0](https://github.com/weijinqian0) | 2025/10 |
| Chuanyu Qin | [@nalinaly](https://github.com/nalinaly) | 2025/10 |

## Contributors

Every release of vLLM Ascend would not have been possible without the following contributors:

Updated on 2025-12-16:
| Number | Contributor | Date | Commit ID |
|:------:|:-----------:|:-----:|:---------:|
| 233 | [@UnifiedCacheManager](https://github.com/UnifiedCacheManager) | 2025/12/16 | [195eac6](https://github.com/vllm-project/vllm-ascend/commit/195eac665b2d42b8287c59128490586c6931d54c) |
| 232 | [@knight0528](https://github.com/knight0528) | 2025/12/15 | [e25c57b](https://github.com/vllm-project/vllm-ascend/commit/e25c57b3461b8116d533724013fbc9957716f92d) |
| 231 | [@ming1212](https://github.com/ming1212) | 2025/12/15 | [98b9e2e](https://github.com/vllm-project/vllm-ascend/commit/98b9e2e18e8f8e9f1495eafc8f57e3e1791e0a34) |
| 230 | [@wangyao-i](https://github.com/wangyao-i) | 2025/12/12 | [0983c55](https://github.com/vllm-project/vllm-ascend/commit/0983c5510aa49c7310b79db72657d8a0f92918ec) |
| 229 | [@sunchendd](https://github.com/sunchendd) | 2025/12/12 | [5932abc](https://github.com/vllm-project/vllm-ascend/commit/5932abc44686cc0d3fa1c4ce9fdbc30957b8aa51) |
| 228 | [@yangshihao6](https://github.com/yangshihao6) | 2025/12/11 | [e1bb6f4](https://github.com/vllm-project/vllm-ascend/commit/e1bb6f47ecabcb382ff3b4dfbd168d0943ce504f) |
| 227 | [@hwhaokun](https://github.com/hwhaokun) | 2025/12/11 | [a47aa4d](https://github.com/vllm-project/vllm-ascend/commit/a47aa4da2f87dfd2792ef13d31476eccd27685bf) |
| 226 | [@xlan-huawei](https://github.com/xlan-huawei) | 2025/12/11 | [5ebb9bd](https://github.com/vllm-project/vllm-ascend/commit/5ebb9bd8d26395e86f9bd01183a327477a966760) |
| 225 | [@zzhx1](https://github.com/zzhx1) | 2025/12/11 | [eac72f5](https://github.com/vllm-project/vllm-ascend/commit/eac72f5f23ac271849bee934859bb8e1c1f16d39) |
| 224 | [@chenjunyi-dev](https://github.com/chenjunyi-dev) | 2025/12/11 | [c12eb22](https://github.com/vllm-project/vllm-ascend/commit/c12eb22cbe9f55ce72fca3d8231c06d0173e22fb) |
| 223 | [@Gongdayao](https://github.com/Gongdayao) | 2025/12/11 | [89a8607](https://github.com/vllm-project/vllm-ascend/commit/89a8607b30ca4f123ae405df42701077b776e4af) |
| 222 | [@ChenCangtao](https://github.com/ChenCangtao) | 2025/12/10 | [dd622aa](https://github.com/vllm-project/vllm-ascend/commit/dd622aa6a6ea34a6bc799d52171ebe6c3e062972) |
| 221 | [@ghphotoframe](https://github.com/ghphotoframe) | 2025/12/10 | [0d8c0f1](https://github.com/vllm-project/vllm-ascend/commit/0d8c0f1a24a58011908b17994fffb5fcfebe5e22) |
| 220 | [@wind-all](https://github.com/wind-all) | 2025/12/10 | [1a443f2](https://github.com/vllm-project/vllm-ascend/commit/1a443f2772ba9a75288e5dc09227ee6bdd54c147) |
| 219 | [@zhoux77899](https://github.com/zhoux77899) | 2025/12/10 | [ce58727](https://github.com/vllm-project/vllm-ascend/commit/ce5872705e80d3e2fb107808aa296831d93fe6fa) |
| 218 | [@Trunrain](https://github.com/Trunrain) | 2025/12/10 | [ba9cda9](https://github.com/vllm-project/vllm-ascend/commit/ba9cda9dfd83765a7e79a074c033818ff5a76bd6) |
| 217 | [@luoxiaolin712](https://github.com/luoxiaolin712) | 2025/12/09 | [dee00d0](https://github.com/vllm-project/vllm-ascend/commit/dee00d0de3528ab5a21adec00fa125f8735f1bb1) |
| 216 | [@wangqiankun13](https://github.com/wangqiankun13) | 2025/12/09 | [9567e5d](https://github.com/vllm-project/vllm-ascend/commit/9567e5dd8c61d2e62b3572c9e98dc4f9eaf51c2a) |
| 215 | [@lhp-deep](https://github.com/lhp-deep) | 2025/12/08 | [b230e7e](https://github.com/vllm-project/vllm-ascend/commit/b230e7e987da602a3985a4f297b01decfc1ec40f) |
| 214 | [@shiro-zzzz](https://github.com/shiro-zzzz) | 2025/12/08 | [0617d7d](https://github.com/vllm-project/vllm-ascend/commit/0617d7d394a9b6aa47a75f368d6059b1e5788f06) |
| 213 | [@zengzengran](https://github.com/zengzengran) | 2025/12/08 | [f0876b5](https://github.com/vllm-project/vllm-ascend/commit/f0876b5d88a04734505bb5cea7bda95b026923ff) |
| 212 | [@lulina](https://github.com/lulina) | 2025/12/08 | [2be0fe2](https://github.com/vllm-project/vllm-ascend/commit/2be0fe269160e97dc9449101e92a98e7f3436668) |
| 211 | [@AlvisGong](https://github.com/AlvisGong) | 2025/12/06 | [a5163c8](https://github.com/vllm-project/vllm-ascend/commit/a5163c8c369e046c53e6127bbbcee23392cec069) |
| 210 | [@GuoRen868](https://github.com/GuoRen868) | 2025/12/06 | [4bd1030](https://github.com/vllm-project/vllm-ascend/commit/4bd1030842a3831109ccfb136056459cd83c1441) |
| 209 | [@h1074112368](https://github.com/h1074112368) | 2025/12/06 | [7403399](https://github.com/vllm-project/vllm-ascend/commit/74033999ed98fcf02db0a2512d019177d0843791) |
| 208 | [@amy-why-3459](https://github.com/amy-why-3459) | 2025/12/03 | [26e8e58](https://github.com/vllm-project/vllm-ascend/commit/26e8e58cea8ba5cc5edaef19e72d0ddc4e9f1c1c) |
| 207 | [@MingYang119](https://github.com/MingYang119) | 2025/12/03 | [18b90b5](https://github.com/vllm-project/vllm-ascend/commit/18b90b501d6aad1d9426dcdee1ccfbe8139dd47d) |
| 206 | [@coder-fny](https://github.com/coder-fny) | 2025/12/02 | [1b5513a](https://github.com/vllm-project/vllm-ascend/commit/1b5513aa914aa37cb539d410faf6e021e6dc5481) |
| 205 | [@fluctlux](https://github.com/fluctlux) | 2025/12/01 | [f1f6370](https://github.com/vllm-project/vllm-ascend/commit/f1f6370ed966bd554f8874ddc430c09f25354c72) |
| 204 | [@swy20190](https://github.com/swy20190) | 2025/12/01 | [f4871c6](https://github.com/vllm-project/vllm-ascend/commit/f4871c6ab98af9ab2766779b2167de04805f38e2) |
| 203 | [@zzhx1](https://github.com/zzhx1) | 2025/12/01 | [2b82320](https://github.com/vllm-project/vllm-ascend/commit/2b82320b6649a9be16d67691c289674ed30b0de4) |
| 202 | [@ChenxiQ](https://github.com/ChenxiQ) | 2025/11/28 | [554f16a](https://github.com/vllm-project/vllm-ascend/commit/554f16ae1fb89b35ad82b24e7f7fe5eaba0e80d0) |
| 201 | [@LHXuuu](https://github.com/LHXuuu) | 2025/11/28 | [bdc6697](https://github.com/vllm-project/vllm-ascend/commit/bdc66972db12cc9f4b63721495fb2b103942dd25) |
| 200 | [@zjchenn](https://github.com/zjchenn) | 2025/11/25 | [463910e](https://github.com/vllm-project/vllm-ascend/commit/463910e686013acc611a7e3ccb70c3a776c8ffef) |
| 199 | [@wujinyuan1](https://github.com/wujinyuan1) | 2025/11/25 | [386a85e](https://github.com/vllm-project/vllm-ascend/commit/386a85eccc9a2247180faad2f8a00ad9c0afa4b1) |
| 198 | [@Tjh-UKN](https://github.com/Tjh-UKN) | 2025/11/24 | [00ea61e](https://github.com/vllm-project/vllm-ascend/commit/00ea61ec885e21ed0e51dc8e751cb27cfa539dc3) |
| 197 | [@mazhixin000](https://github.com/mazhixin000) | 2025/11/22 | [ab51fce](https://github.com/vllm-project/vllm-ascend/commit/ab51fcea4ca77fdb642a04018df60e18586d52ef) |
| 196 | [@shenchuxiaofugui](https://github.com/shenchuxiaofugui) | 2025/11/21 | [019c7de](https://github.com/vllm-project/vllm-ascend/commit/019c7ded91f0c2a9533ace8d87f0cf56e396f979) |
| 195 | [@InSec](https://github.com/InSec) | 2025/11/21 | [5a4e8cd](https://github.com/vllm-project/vllm-ascend/commit/5a4e8cdebabd8293e9ff61b7014d758b71ebf32a) |
| 194 | [@Delphine-Nic](https://github.com/Delphine-Nic) | 2025/11/19 | [a3e9673](https://github.com/vllm-project/vllm-ascend/commit/a3e9673137dd31d77b7441d657a0fc394ac7bc59) |
| 193 | [@1092626063](https://github.com/1092626063) | 2025/11/19 | [9328f37](https://github.com/vllm-project/vllm-ascend/commit/9328f377b4dd3c6dd8915b7c60ae01335fc554c4) |
| 192 | [@wangxiaochao6](https://github.com/wangxiaochao6) | 2025/11/18 | [0d04ad8](https://github.com/vllm-project/vllm-ascend/commit/0d04ad8c8f00081932566576da1e6d1dcd963d8d) |
| 191 | [@845473182](https://github.com/845473182) | 2025/11/14 | [f90ed95](https://github.com/vllm-project/vllm-ascend/commit/f90ed95578f81ddd1cb96c9bd5d6ef8be8475667) |
| 190 | [@thonean](https://github.com/thonean) | 2025/11/12 | [e38fe92](https://github.com/vllm-project/vllm-ascend/commit/e38fe92f4037fe668f34b23c67daa9695a3fc3c7) |
| 189 | [@Apocalypse990923-qshi](https://github.com/Apocalypse990923-qshi) | 2025/11/11 | [71866d5](https://github.com/vllm-project/vllm-ascend/commit/71866d531151b36a9af4db36ba8b3b74162f7028) |
| 188 | [@zhaomingyu13](https://github.com/zhaomingyu13) | 2025/11/11 | [7ffbe73](https://github.com/vllm-project/vllm-ascend/commit/7ffbe73d54d7257c571ddd21bac6543b5ead0dac) |
| 187 | [@herizhen](https://github.com/herizhen) | 2025/11/10 | [75c3f9a](https://github.com/vllm-project/vllm-ascend/commit/75c3f9a7807daa3346685be88e4f06d6a5f362f0) |
| 186 | [@wangx700](https://github.com/wangx700) | 2025/11/08 | [55e37f5](https://github.com/vllm-project/vllm-ascend/commit/55e37f50418f38861768556fdde9e86c2a22aef4) |
| 185 | [@Semmer2](https://github.com/Semmer2) | 2025/11/08 | [f984256](https://github.com/vllm-project/vllm-ascend/commit/f9842560cbd5bb7b1106b3f47982adb479a91774) |
| 184 | [@Liziqi-77](https://github.com/Liziqi-77) | 2025/11/06 | [25b24c0](https://github.com/vllm-project/vllm-ascend/commit/25b24c02ea86f0f8a673f8f332e800ed72abc083) |
| 183 | [@Pz1116](https://github.com/Pz1116) | 2025/11/05 | [e0c23cb](https://github.com/vllm-project/vllm-ascend/commit/e0c23cb011e7ee6e5afce32ab0a0b9c73e825baa) |
| 182 | [@MrZ20](https://github.com/MrZ20) | 2025/11/04 | [dc1a6cb](https://github.com/vllm-project/vllm-ascend/commit/dc1a6cb5039b5ee1520fde8cf85b99f7ce33ec7b) |
| 181 | [@ForBetterCodeNine](https://github.com/ForBetterCodeNine) | 2025/11/03 | [49d7478](https://github.com/vllm-project/vllm-ascend/commit/49d74785c440c964db1a1212c9b24f695f21a5a2) |
| 180 | [@gcanlin](https://github.com/gcanlin) | 2025/10/31 | [f99762e](https://github.com/vllm-project/vllm-ascend/commit/f99762eb254807335419cd04945359eaa5213713) |
| 179 | [@Nagisa125](https://github.com/Nagisa125) | 2025/10/31 | [6764777](https://github.com/vllm-project/vllm-ascend/commit/6764777f000f6ac5acfadbba3797ce966397e1d8) |
| 178 | [@Liwx1014](https://github.com/Liwx1014) | 2025/10/30 | [eed1957](https://github.com/vllm-project/vllm-ascend/commit/eed1957f03224bf800191390244c39ff5bb362d1) |
| 177 | [@Meihan-chen](https://github.com/Meihan-chen) | 2025/10/29 | [cba69e1](https://github.com/vllm-project/vllm-ascend/commit/cba69e117eaa8c5d31fca64b01aecb22d3162860) |
| 176 | [@Levi-JQ](https://github.com/Levi-JQ) | 2025/10/27 | [d64bdd0](https://github.com/vllm-project/vllm-ascend/commit/d64bdd06ae656048040c34c0ff3b909293b5113b) |
| 175 | [@ck-hw-1018](https://github.com/ck-hw-1018) | 2025/10/25 | [7572939](https://github.com/vllm-project/vllm-ascend/commit/7572939b94e9c2215cf3ebd30bd6f61c4d1b04f6) |
| 174 | [@QilaiZhang](https://github.com/QilaiZhang) | 2025/10/25 | [d30bb95](https://github.com/vllm-project/vllm-ascend/commit/d30bb95b9040475495dc01f5c9e38576905be621) |
| 173 | [@gcanlin](https://github.com/gcanlin) | 2025/10/25 | [8295136](https://github.com/vllm-project/vllm-ascend/commit/829513657518c0077622b1904f49d79657b2537a) |
| 172 | [@luoxiaolin712](https://github.com/luoxiaolin712) | 2025/10/24 | [59bb16b](https://github.com/vllm-project/vllm-ascend/commit/59bb16b75c492aa636fec53f1d32680839e7d1e7) |
| 171 | [@yenuo26](https://github.com/yenuo26) | 2025/10/24 | [d301c56](https://github.com/vllm-project/vllm-ascend/commit/d301c56d1aff5d2f408e54285df5ff36fd28d193) |
| 170 | [@lio1226](https://github.com/lio1226) | 2025/10/24 | [cd58a64](https://github.com/vllm-project/vllm-ascend/commit/cd58a643c598622fdf5a853764f851a5074d0328) |
| 169 | [@HuaJiaHeng](https://github.com/HuaJiaHeng) | 2025/10/23 | [062257f](https://github.com/vllm-project/vllm-ascend/commit/062257f624486d15315013b624ce71e1a388ee20) |
| 168 | [@destinysky](https://github.com/destinysky) | 2025/10/23 | [427b17e](https://github.com/vllm-project/vllm-ascend/commit/427b17e2da1d6d967e7581b40b6bd169cdb324c8) |
| 167 | [@yzy1996](https://github.com/yzy1996) | 2025/10/23 | [f06a6ca](https://github.com/vllm-project/vllm-ascend/commit/f06a6cad1b0c6b142d4a9364c65b4b920b251540) |
| 166 | [@HF-001](https://github.com/HF-001) | 2025/10/22 | [bc30874](https://github.com/vllm-project/vllm-ascend/commit/bc30874f8b6212ff8eb45b2546c360660c49c9c1) |
| 165 | [@KyrieDrewWang](https://github.com/KyrieDrewWang) | 2025/10/22 | [60e2be1](https://github.com/vllm-project/vllm-ascend/commit/60e2be1b366975f7183c38cd158da811969b9230) |
| 164 | [@Pr0Wh1teGivee](https://github.com/Pr0Wh1teGivee) | 2025/10/22 | [2f1b9a7](https://github.com/vllm-project/vllm-ascend/commit/2f1b9a7a641b58e49b760311d06cd81091faff12) |
| 163 | [@drslark](https://github.com/drslark) | 2025/10/21 | [534f32d](https://github.com/vllm-project/vllm-ascend/commit/534f32d27c0cc48731fbdae3701fbb6c3bb4332a) |
| 162 | [@Anionex](https://github.com/Anionex) | 2025/10/21 | [5f8b169](https://github.com/vllm-project/vllm-ascend/commit/5f8b1699ae35bb8c046d8b385d215cd208bc3fcb) |
| 161 | [@kiscad](https://github.com/kiscad) | 2025/10/21 | [6b290ac](https://github.com/vllm-project/vllm-ascend/commit/6b290acfe109bdfd9225a6c06a89f2dcba7a4156) |
| 160 | [@leijie-ww](https://github.com/leijie-ww) | 2025/10/20 | [6b68579](https://github.com/vllm-project/vllm-ascend/commit/6b6857929d8397fbec1cd132eb4ea5d13712497c) |
| 159 | [@ZYang6263](https://github.com/ZYang6263) | 2025/10/19 | [1e78ecb](https://github.com/vllm-project/vllm-ascend/commit/1e78ecbad626968c7e65fab5596c90ea79e7454d) |
| 158 | [@Shirley125](https://github.com/Shirley125) | 2025/10/18 | [b4233a2](https://github.com/vllm-project/vllm-ascend/commit/b4233a2ec35a91beca4b8c8402ea7cf6394b62c9) |
| 157 | [@yechao237](https://github.com/yechao237) | 2025/10/18 | [4750d45](https://github.com/vllm-project/vllm-ascend/commit/4750d45d86632b7085ab9f0b57070cd17aa9d108) |
| 156 | [@DreamerLeader](https://github.com/DreamerLeader) | 2025/10/15 | [aa61547](https://github.com/vllm-project/vllm-ascend/commit/aa6154703aeeb259611326a3fba095b6abc5b791) |
| 155 | [@yuzhup](https://github.com/yuzhup) | 2025/10/14 | [7877723](https://github.com/vllm-project/vllm-ascend/commit/78777237a9ae95af88ce6068b000635f96aafe25) |
| 154 | [@elilzhu](https://github.com/elilzhu) | 2025/10/14 | [5c45c22](https://github.com/vllm-project/vllm-ascend/commit/5c45c227dc254591f4a9345e67a84a0d5fe1c345) |
| 153 | [@menogrey](https://github.com/menogrey) | 2025/10/14 | [657c08c](https://github.com/vllm-project/vllm-ascend/commit/657c08cfb266c63946ea61a7be377b6de55d20f3) |
| 152 | [@SlightwindSec](https://github.com/SlightwindSec) | 2025/10/13 | [4f6d60e](https://github.com/vllm-project/vllm-ascend/commit/4f6d60eb067996fbf08b95f797916d978bf98f19) |
| 151 | [@dsxsteven](https://github.com/dsxsteven) | 2025/10/13 | [847d12a](https://github.com/vllm-project/vllm-ascend/commit/847d12a389217e4cbcc5fff70abd72d9b15ad5c4) |
| 150 | [@jiangyunfan1](https://github.com/jiangyunfan1) | 2025/10/12 | [d05d29f](https://github.com/vllm-project/vllm-ascend/commit/d05d29ff0e7c5d261dbdee5e98ff0ca95135217b) |
| 149 | [@kiscad](https://github.com/kiscad) | 2025/10/12 | [bcc313e](https://github.com/vllm-project/vllm-ascend/commit/bcc313e8f2bfe9a53ed88dffffd93632db52a4ba) |
| 148 | [@wangxiaoteng888](https://github.com/wangxiaoteng888) | 2025/10/11 | [ca05f7d](https://github.com/vllm-project/vllm-ascend/commit/ca05f7d63267c6e77fd1c297264970ed19e17620) |
| 147 | [@huangdong2022](https://github.com/huangdong2022) | 2025/10/09 | [23db56a](https://github.com/vllm-project/vllm-ascend/commit/23db56a34063c5285f7d34e80e45c1888b877bd3) |

Updated on 2025-09-30:

| Number | Contributor | Date | Commit ID |
|:------:|:-----------:|:-----:|:---------:|
| 146 | [@socrahow](https://github.com/socrahow) | 2025/9/28 | [c3fee66](https://github.com/vllm-project/vllm-ascend/commit/c3fee66806f252476796389ea73d13a8aca60146) |
| 145 | [@slippersss](https://github.com/slippersss) | 2025/9/28 | [a86ece5](https://github.com/vllm-project/vllm-ascend/commit/a86ece5e399db9aa9d7186ab7e51bc0e0dad4134) |
| 144 | [@florenceCH](https://github.com/florenceCH) | 2025/9/26 | [14497b7](https://github.com/vllm-project/vllm-ascend/commit/14497b748d778f95328f55a957e997ad80a492da) |
| 143 | [@dragondream-chen](https://github.com/dragondream-chen) | 2025/9/25 | [07f4710](https://github.com/vllm-project/vllm-ascend/commit/07f4710216da1d61c521fb3bdf4ba90ea1794474) |
| 142 | [@mfyCn-1204](https://github.com/mfyCn-1204) | 2025/9/25 | [33c118c](https://github.com/vllm-project/vllm-ascend/commit/33c118c80e70cec64c9369b7ba4088c61c44bd31) |
| 141 | [@zzhx1](https://github.com/zzhx1) | 2025/9/24 | [4ee58e2](https://github.com/vllm-project/vllm-ascend/commit/4ee58e213b421ece745dba6e94967e6f557263ce) |
| 140 | [@clrs97](https://github.com/clrs97) | 2025/9/24 | [cd1ffbb](https://github.com/vllm-project/vllm-ascend/commit/cd1ffbb6cd88a3f265027424bd3cca74d1efb1ea) |
| 139 | [@Clorist33](https://github.com/Clorist33) | 2025/9/24 | [302494c](https://github.com/vllm-project/vllm-ascend/commit/302494c1febfb648ac2a5001390bbd9b59db6bc2) |
| 138 | [@Csrayz](https://github.com/Csrayz) | 2025/9/24 | [80524f5](https://github.com/vllm-project/vllm-ascend/commit/80524f571152e978f6e2808e504e1aa8b246a2c1) |
| 137 | [@booker123456](https://github.com/booker123456) | 2025/9/24 | [c4b976a](https://github.com/vllm-project/vllm-ascend/commit/c4b976af1a6459a82f7556c53dc98c850dd3e3cd) |
| 136 | [@MaoJianwei](https://github.com/MaoJianwei) | 2025/9/23 | [d586255](https://github.com/vllm-project/vllm-ascend/commit/d586255678d974d74b1fe798838594c0e948d6b6) |
| 135 | [@Mercykid-bash](https://github.com/Mercykid-bash) | 2025/9/23 | [29c173a](https://github.com/vllm-project/vllm-ascend/commit/29c173ab48001f3d26805db2d833be712687fb1a) |
| 134 | [@qyqc731](https://github.com/qyqc731) | 2025/9/22 | [f1f2c8f](https://github.com/vllm-project/vllm-ascend/commit/f1f2c8f5e5d1659a97edc5cde7b7d80b8426416a) |
| 133 | [@Lucaskabela](https://github.com/Lucaskabela) | 2025/9/20 | [53ecd89](https://github.com/vllm-project/vllm-ascend/commit/53ecd89e8ff405302be040a76effa8c012cbaaeb) |
| 132 | [@jesse996](https://github.com/jesse996) | 2025/9/19 | [833cd1b](https://github.com/vllm-project/vllm-ascend/commit/833cd1b698f3d467bb0a6a60cbf20ebc5535f5c9) |
| 131 | [@1Fire4](https://github.com/1Fire4) | 2025/9/17 | [1f6465c](https://github.com/vllm-project/vllm-ascend/commit/1f6465c399d6e699f88e28419c106573bd6c44f0) |
| 130 | [@offline893](https://github.com/offline893) | 2025/9/17 | [76844ee](https://github.com/vllm-project/vllm-ascend/commit/76844eec78a23f482a4e0dfe9684898a6ef35fb2) |
| 129 | [@nwpu-zxr](https://github.com/nwpu-zxr) | 2025/9/13 | [0a27705](https://github.com/vllm-project/vllm-ascend/commit/0a27705917e64993a8a76198ac6e30980578fe60) |
| 128 | [@wyu0-0](https://github.com/wyu0-0) | 2025/9/11 | [eab3635](https://github.com/vllm-project/vllm-ascend/commit/eab3635850ba351af81d76a7b4b3db46ffb7f697) |
| 127 | [@wuweiqiang24](https://github.com/wuweiqiang24) | 2025/9/11 | [9615dea](https://github.com/vllm-project/vllm-ascend/commit/9615dea3a71df8ecd2c591f284d9615140dce68a) |
| 126 | [@wenba0](https://github.com/wenba0) | 2025/9/11 | [bd3dede](https://github.com/vllm-project/vllm-ascend/commit/bd3dedea6123c9c8c19fe83b6e05716f63b1285d) |
| 125 | [@zhaozx-cn](https://github.com/zhaozx-cn) | 2025/9/11 | [b9a0a75](https://github.com/vllm-project/vllm-ascend/commit/b9a0a75c783571caf22129612fb3338272d1782c) |
| 124 | [@anon189Ty](https://github.com/anon189Ty) |  2025/9/11| [7b2ecc1](https://github.com/vllm-project/vllm-ascend/commit/7b2ecc1e9a64aeda78e2137aa06abdbf2890c000) |
| 123 | [@FFFrog](https://github.com/FFFrog) | 2025/9/10 | [b7ee3fd](https://github.com/vllm-project/vllm-ascend/commit/b7ee3fdad30d00d9aaa31be04315838c7e2c24ac) |
| 122 | [@machenglong2025](https://github.com/machenglong2025) | 2025/9/08 | [1a82b16](https://github.com/vllm-project/vllm-ascend/commit/1a82b16355d2ec0ba01c23935092dc0af323b820) |
| 121 | [@realliujiaxu](https://github.com/realliujiaxu) | 2025/9/08 | [d3c3538](https://github.com/vllm-project/vllm-ascend/commit/d3c3538ddc67ba8f4873637e2bc1052f9eb09e93) |
| 120 | [@marcobarlo](https://github.com/marcobarlo) | 2025/9/08 | [6666e52](https://github.com/vllm-project/vllm-ascend/commit/6666e5265d40ecafc3cb377233fee840d7fe553b) |
| 119 | [@1092626063](https://github.com/1092626063) | 2025/9/05 | [5b3646a](https://github.com/vllm-project/vllm-ascend/commit/5b3646ab2142131579661ce12e4f0e4ba731ad06)|
| 118 | [@WithHades](https://github.com/WithHades) | 2025/9/04 | [0c0789b](https://github.com/vllm-project/vllm-ascend/commit/0c0789be7442122eb1203abbf89a9592648922e0) |
| 117 | [@panchao-hub](https://github.com/panchao-hub) | 2025/8/30 | [7215454](https://github.com/vllm-project/vllm-ascend/commit/7215454de6df78f4f9a49a99c5739f8bb360f5bc) |
| 116 | [@lidenghui1110](https://github.com/lidenghui1110) | 2025/8/29 | [600b08f](https://github.com/vllm-project/vllm-ascend/commit/600b08f7542be3409c2c70927c91471e8de33d03) |
| 115 | [@NSDie](https://github.com/NSDie) | 2025/8/28 | [1191a64](https://github.com/vllm-project/vllm-ascend/commit/1191a64ae508183d5613711bc98a90250963f83a) |
| 114 | [@s-jiayang](https://github.com/s-jiayang) | 2025/8/27 | [6a4ec18](https://github.com/vllm-project/vllm-ascend/commit/6a4ec186e731b9516235f4fd30b5b98227513fe7) |
| 113 | [@LookAround0301](https://github.com/LookAround0301) | 2025/8/22 | [e9fb895](https://github.com/vllm-project/vllm-ascend/commit/e9fb895b10cef37ea634f4d4af71686b09ca9f20) |
| 112 | [@ZhaoJiangJiang](https://github.com/ZhaoJiangJiang) | 2025/8/22 | [3629bc4](https://github.com/vllm-project/vllm-ascend/commit/3629bc4431d3edb4224761f9036b3bddb16158d6) |
| 111 | [@NicholasTao](https://github.com/NicholasTao) | 2025/8/20 | [7bec1a9](https://github.com/vllm-project/vllm-ascend/commit/7bec1a9b9c372785551d45682bf11063ec42b216) |
| 110 | [@gameofdimension](https://github.com/gameofdimension) | 2025/8/19 | [27d038d](https://github.com/vllm-project/vllm-ascend/commit/27d038dc663bf550a35a8f15659493b2abefda07) |
| 109 | [@liuchenbing](https://github.com/liuchenbing) | 2025/8/19 | [3648d18](https://github.com/vllm-project/vllm-ascend/commit/3648d18e673f15a33a82d6ea95d3a9dd891ff1f5) |
| 108 | [@LCAIZJ](https://github.com/LCAIZJ) | 2025/8/18 | [03ca2b2](https://github.com/vllm-project/vllm-ascend/commit/03ca2b26ca9ab6b9a12f021b0595a726ee35e223) |
| 107 | [@haojiangzheng](https://github.com/haojiangzheng) | 2025/8/11 | [eb43a47](https://github.com/vllm-project/vllm-ascend/commit/eb43a475f429192e7509e85e28b1c65d5097f373) |
| 106 | [@QwertyJack](https://github.com/QwertyJack) | 2025/8/11 | [9c6d108](https://github.com/vllm-project/vllm-ascend/commit/9c6d108330574176f79eea52f989ea6049336af8) |
| 105 | [@SlightwindSec](https://github.com/SlightwindSec) | 2025/8/5 | [f3b50c5](https://github.com/vllm-project/vllm-ascend/commit/f3b50c54e8243ad8ccefb9b033277fbdd382a9c4) |
| 104 | [@CaveNightingale](https://github.com/CaveNightingale) | 2025/8/4 | [957c7f1](https://github.com/vllm-project/vllm-ascend/commit/957c7f108d5f0aea230220ccdc18d657229e4030) |
| 103 | [@underfituu](https://github.com/underfituu) | 2025/8/4 | [e38fab0](https://github.com/vllm-project/vllm-ascend/commit/e38fab011d0b81f3a8e40d9bbe263c283dd4129b) |
| 102 | [@yangqinghao-cmss](https://github.com/yangqinghao-cmss) | 2025/8/1 | [99fa0ac](https://github.com/vllm-project/vllm-ascend/commit/99fa0ac882c79ae9282940125b042a44ea422757) |
| 101 | [@pjgao](https://github.com/pjgao) | 2025/7/31 | [6192bc9](https://github.com/vllm-project/vllm-ascend/commit/6192bc95c0e47097836e9be1f30f2a0a6fdca088) |
| 100 | [@Liccol](https://github.com/Liccol) | 2025/7/31 | [7c90ba5](https://github.com/vllm-project/vllm-ascend/commit/7c90ba5fe8e420b891fdd30df050a33e3767835d) |
| 99 | [@1024daniel](https://github.com/1024daniel) | 2025/7/31 | [db310c6](https://github.com/vllm-project/vllm-ascend/commit/db310c6ec97b056296f7c2348b90c1d96d0b562a) |
| 98 | [@zhoux77899](https://github.com/zhoux77899) | 2025/7/30 | [4fcca13](https://github.com/vllm-project/vllm-ascend/commit/4fcca137a70c11daa4070ae014288be154715939) |
| 97 | [@YuanCheng-coder](https://github.com/YuanCheng-coder) | 2025/7/30 | [34dd24a](https://github.com/vllm-project/vllm-ascend/commit/34dd24adf21fb85a2c413292754b1599832efae2) |
| 96 | [@hongfugui](https://github.com/hongfugui) | 2025/7/30 | [1dbb888](https://github.com/vllm-project/vllm-ascend/commit/1dbb8882759e4326f5706f6e610674423376c2f3) |
| 95 | [@Irving11-BKN](https://github.com/Irving11-BKN) | 2025/7/29 | [ca8007f](https://github.com/vllm-project/vllm-ascend/commit/ca8007f584141d3a59b2bcbd4f8ba269c9b7e252) |
| 94 | [@taoxudonghaha](https://github.com/taoxudonghaha) | 2025/7/29 | [540336e](https://github.com/vllm-project/vllm-ascend/commit/540336edc9db09072a9aaa486fbf7ce625da5b9e) |
| 93 | [@loukong33](https://github.com/loukong33) | 2025/7/28 | [1a25b0a](https://github.com/vllm-project/vllm-ascend/commit/1a25b0a2ddb23bf4d731ebac4503efaf237b191f) |
| 92 | [@Ronald1995](https://github.com/Ronald1995) | 2025/7/25 | [e561a2c](https://github.com/vllm-project/vllm-ascend/commit/e561a2c6ec4493b490b13a4a9007d8f451ae0d0f) |
| 91 | [@ZrBac](https://github.com/ZrBac) | 2025/7/24 | [2ffe051](https://github.com/vllm-project/vllm-ascend/commit/2ffe051859d585df8353d1b9eefb64c44078175a) |
| 90 | [@SunnyLee151064](https://github.com/SunnyLee151064) | 2025/7/24 | [34571ea](https://github.com/vllm-project/vllm-ascend/commit/34571ea5ae69529758edf75f0252f86ccb4c7184) |
| 89 | [@shiyuan680](https://github.com/shiyuan680) | 2025/7/23 | [ac0bf13](https://github.com/vllm-project/vllm-ascend/commit/ac0bf133f47ead20f18bf71f9be6dbe05fbd218f) |
| 88 | [@aidoczh](https://github.com/aidoczh) | 2025/7/21 | [c32eea9](https://github.com/vllm-project/vllm-ascend/commit/c32eea96b73d26268070f57ef98416decc98aff7) |
| 87 | [@nuclearwu](https://github.com/nuclearwu) | 2025/7/20 | [54f2b31](https://github.com/vllm-project/vllm-ascend/commit/54f2b311848badc86371d269140e729012a60f2c) |
| 86 | [@pkking](https://github.com/pkking) | 2025/7/18 | [3e39d72](https://github.com/vllm-project/vllm-ascend/commit/3e39d7234c0e5c66b184c136c602e87272b5a36e) |
| 85 | [@lianyiibo](https://github.com/lianyiibo) | 2025/7/18 | [53d2ea3](https://github.com/vllm-project/vllm-ascend/commit/53d2ea3789ffce32bf3ceb055d5582d28eadc6c7) |
| 84 | [@xudongLi-cmss](https://github.com/xudongLi-cmss) | 2025/7/2 | [7fc1a98](https://github.com/vllm-project/vllm-ascend/commit/7fc1a984890bd930f670deedcb2dda3a46f84576) |
| 83 | [@ZhengWG](https://github.com/) | 2025/7/7 | [3a469de](https://github.com/vllm-project/vllm-ascend/commit/9c886d0a1f0fc011692090b0395d734c83a469de) |
| 82 | [@wm901115nwpu](https://github.com/) | 2025/7/7 | [a2a47d4](https://github.com/vllm-project/vllm-ascend/commit/f08c4f15a27f0f27132f4ca7a0c226bf0a2a47d4) |
| 81 | [@Agonixiaoxiao](https://github.com/) | 2025/7/2 | [6f84576](https://github.com/vllm-project/vllm-ascend/commit/7fc1a984890bd930f670deedcb2dda3a46f84576) |
| 80 | [@zhanghw0354](https://github.com/zhanghw0354) | 2025/7/2 | [d3df9a5](https://github.com/vllm-project/vllm-ascend/commit/9fb3d558e5b57a3c97ee5e11b9f5dba6ad3df9a5) |
| 79 | [@GDzhu01](https://github.com/GDzhu01) | 2025/6/28 | [de256ac](https://github.com/vllm-project/vllm-ascend/commit/b308a7a25897b88d4a23a9e3d583f4ec6de256ac) |
| 78 | [@leo-pony](https://github.com/leo-pony) | 2025/6/26 | [3f2a5f2](https://github.com/vllm-project/vllm-ascend/commit/10253449120307e3b45f99d82218ba53e3f2a5f2) |
| 77 | [@zeshengzong](https://github.com/zeshengzong) | 2025/6/26 | [3ee25aa](https://github.com/vllm-project/vllm-ascend/commit/192dbbcc6e244a8471d3c00033dc637233ee25aa) |
| 76 | [@sharonyunyun](https://github.com/sharonyunyun) | 2025/6/25 | [2dd8666](https://github.com/vllm-project/vllm-ascend/commit/941269a6c5bbc79f6c1b6abd4680dc5802dd8666) |
| 75 | [@Pr0Wh1teGivee](https://github.com/Pr0Wh1teGivee) | 2025/6/25 | [c65dd40](https://github.com/vllm-project/vllm-ascend/commit/2fda60464c287fe456b4a2f27e63996edc65dd40) |
| 74 | [@xleoken](https://github.com/xleoken) | 2025/6/23 | [c604de0](https://github.com/vllm-project/vllm-ascend/commit/4447e53d7ad5edcda978ca6b0a3a26a73c604de0) |
| 73 | [@lyj-jjj](https://github.com/lyj-jjj) | 2025/6/23 | [5cbd74e](https://github.com/vllm-project/vllm-ascend/commit/5177bef87a21331dcca11159d3d1438075cbd74e) |
| 72 | [@farawayboat](https://github.com/farawayboat)| 2025/6/21 | [bc7d392](https://github.com/vllm-project/vllm-ascend/commit/097e7149f75c0806774bc68207f0f6270bc7d392)
| 71 | [@yuancaoyaoHW](https://github.com/yuancaoyaoHW) | 2025/6/20 | [7aa0b94](https://github.com/vllm-project/vllm-ascend/commit/00ae250f3ced68317bc91c93dc1f1a0977aa0b94)
| 70 | [@songshanhu07](https://github.com/songshanhu07) | 2025/6/18 | [5e1de1f](https://github.com/vllm-project/vllm-ascend/commit/2a70dbbdb8f55002de3313e17dfd595e1de1f)
| 69 | [@wangyanhui-cmss](https://github.com/wangyanhui-cmss) | 2025/6/12| [40c9e88](https://github.com/vllm-project/vllm-ascend/commit/2a5fb4014b863cee6abc3009f5bc5340c9e88) |
| 68 | [@chenwaner](https://github.com/chenwaner) | 2025/6/11 | [c696169](https://github.com/vllm-project/vllm-ascend/commit/e46dc142bf1180453c64226d76854fc1ec696169) |
| 67 | [@yzim](https://github.com/yzim) | 2025/6/11 | [aaf701b](https://github.com/vllm-project/vllm-ascend/commit/4153a5091b698c2270d160409e7fee73baaf701b) |
| 66 | [@Yuxiao-Xu](https://github.com/Yuxiao-Xu) | 2025/6/9 | [6b853f1](https://github.com/vllm-project/vllm-ascend/commit/6b853f15fe69ba335d2745ebcf14a164d0bcc505) |
| 65 | [@ChenTaoyu-SJTU](https://github.com/ChenTaoyu-SJTU) | 2025/6/7 | [20dedba](https://github.com/vllm-project/vllm-ascend/commit/20dedba5d1fc84b7ae8b49f9ce3e3649389e2193) |
| 64 | [@zxdukki](https://github.com/zxdukki) | 2025/6/7 | [87ebaef](https://github.com/vllm-project/vllm-ascend/commit/87ebaef4e4e519988f27a6aa378f614642202ecf) |
| 63 | [@sdmyzlp](https://github.com/sdmyzlp) | 2025/6/7 | [3640c60](https://github.com/vllm-project/vllm-ascend/commit/3640c60b0eb4d4cb104e20bfa406d3f1d17920a7) |
| 62 | [@weijinqian0](https://github.com/weijinqian0) | 2025/6/7 | [e9ada68](https://github.com/vllm-project/vllm-ascend/commit/e9ada685ece798f9fe0d4a287e3f5246a8a7207b) |
| 61 | [@hahazhky](https://github.com/hahazhky) | 2025/6/6 | [0b12c2a](https://github.com/vllm-project/vllm-ascend/commit/0b12c2acf7d9fd192beebebf662298067d9a5435) |
| 60 | [@depeng1994](https://github.com/depeng1994) | 2025/6/6 | [6b094a2](https://github.com/vllm-project/vllm-ascend/commit/6b094a2bd49a8a41eb3647568b2d9e5b337db81f) |
| 59 | [@David9857](https://github.com/David9857) | 2025/6/5 | [78431b3](https://github.com/vllm-project/vllm-ascend/commit/78431b34694dfa3c8f54ed7cc626660318557927) |
| 58 | [@momo609](https://github.com/momo609) | 2025/6/5 | [908a851](https://github.com/vllm-project/vllm-ascend/commit/908a851a776cfd9051cc062119e6ec481561c6f7) |
| 57 | [@zhangxinyuehfad](https://github.com/zhangxinyuehfad) | 2025/6/5 | [7737aaa](https://github.com/vllm-project/vllm-ascend/commit/7737aaa40f699b233a35fb61e908b687adc1e2e5) |
| 56 | [@NINGBENZHE](https://github.com/NINGBENZHE) | 2025/6/3 | [6ec64a3](https://github.com/vllm-project/vllm-ascend/commit/6ec64a3f9686df65b5a23a41aa301e669db19099) |
| 55 | [@XWFAlone](https://github.com/XWFAlone) | 2025/5/30 | [3442fbd](https://github.com/vllm-project/vllm-ascend/commit/3442fbdb235b4c6d72c2bc64a49707a7bd89958e) |
| 54 | [@YisongJiang](https://github.com/YisongJiang) | 2025/5/29 | [90afaf6](https://github.com/vllm-project/vllm-ascend/commit/90afaf6306f680307462becf3c78585737579851) |
| 53 | [@ponix-j](https://github.com/ponix-j) | 2025/5/23 | [df58fb8](https://github.com/vllm-project/vllm-ascend/commit/df58fb80eee24139fc61c495be3ce79cf81b3f73) |
| 52 | [@ttanzhiqiang](https://github.com/ttanzhiqiang) | 2025/5/23 | [dc6172e](https://github.com/vllm-project/vllm-ascend/commit/dc6172efd3860ce95b40a7b3e93611f875f06d40) |
| 51 | [@yangpuPKU](https://github.com/yangpuPKU) | 2025/5/23 | [46df67a](https://github.com/vllm-project/vllm-ascend/commit/46df67a5e9ab73fade08cbb2d8c0155cee7316d1) |
| 50 | [@wonderful199082](https://github.com/wonderful199082) | 2025/5/20 | [5cf9ff1](https://github.com/vllm-project/vllm-ascend/commit/5cf9ff18e91b0b7031c258d71a257b8e24689763) |
| 49 | [@22dimensions](https://github.com/22dimensions) | 2025/5/17 | [a8730e7](https://github.com/vllm-project/vllm-ascend/commit/a8730e7a3c4ac6c4b39a5946c943252fdea6cce5) |
| 48 | [@cxcxflying](https://github.com/cxcxflying) | 2025/5/13 | [e564470](https://github.com/vllm-project/vllm-ascend/commit/e56447033889ca95df512208cab22ef832bfdf07) |
| 47 | [@NeverRaR](https://github.com/NeverRaR) | 2025/5/12 | [efabd72](https://github.com/vllm-project/vllm-ascend/commit/efabd722eb757e49aa309c173bbec91ca8c4ced1) |
| 46 | [@chris668899](https://github.com/chris668899) | 2025/5/8 | [6c02088](https://github.com/vllm-project/vllm-ascend/commit/6c020883a8332b5c519f4f6502733edd9b391c2b) |
| 45 | [@sunbaosong](https://github.com/sunbaosong) | 2025/5/6 | [d6bfae8](https://github.com/vllm-project/vllm-ascend/commit/d6bfae8eeebedf677b643b712d367a3a69c9cce4) |
| 44 | [@ApsarasX](https://github.com/ApsarasX) | 2025/4/29 | [87975fa](https://github.com/vllm-project/vllm-ascend/commit/87975fa058fe3f90d204ded42a08989a8dcb413e) |
| 43 | [@zouyida2052](https://github.com/zouyida2052) | 2025/4/28 | [b9528e6](https://github.com/vllm-project/vllm-ascend/commit/b9528e6ecdc417cf444e55a0ce4a2bafdef0ea3b) |
| 42 | [@ZhengJun9](https://github.com/ZhengJun9) | 2025/4/28 | [1791113](https://github.com/vllm-project/vllm-ascend/commit/17911138c90d78a76bd691e9dcb56763db35b19f) |
| 41 | [@linfeng-yuan](https://github.com/linfeng-yuan) | 2025/4/28 | [2204e4d](https://github.com/vllm-project/vllm-ascend/commit/2204e4d08f8e10cf9c30154a14eaa5ca956c2acd) |
| 40 | [@jianzs](https://github.com/jianzs) | 2025/4/27 | [fa4a5d9](https://github.com/vllm-project/vllm-ascend/commit/fa4a5d980e8845a88b9162cf169f0a5ab230f8a5) |
| 39 | [@fakeYan](https://github.com/fakeYan) | 2025/4/23 | [05bdcbe](https://github.com/vllm-project/vllm-ascend/commit/05bdcbeae47c7fcb9b1c30cad059abf1d40b5421) |
| 38 | [@RongRongStudio](https://github.com/RongRongStudio) | 2025/4/22 | [848e041](https://github.com/vllm-project/vllm-ascend/commit/848e041a54732c923660dd02daf8e9bf439736a2) |
| 37 | [@paulyu12](https://github.com/paulyu12) | 2025/4/17 | [697908f](https://github.com/vllm-project/vllm-ascend/commit/697908f5cd7c65a3a917ec1a962b0886efc98c7e) |
| 36 | [@heartStrive1998](https://github.com/heartStrive1998) | 2025/4/16 | [2f15503](https://github.com/vllm-project/vllm-ascend/commit/2f155039dc3997640854daef469bbf0cb77dc6ed) |
| 35 | [@eeethenQ](https://github.com/eeethenQ) | 2025/4/15 | [44a8301](https://github.com/vllm-project/vllm-ascend/commit/44a8301424ded94dae83e13b837f5bfc0a1bfc15) |
| 34 | [@wxsIcey](https://github.com/wxsIcey) | 2025/4/10 | [d05ea17](https://github.com/vllm-project/vllm-ascend/commit/d05ea17427b82a506b97409a7de8359f18f565f7) |
| 33 | [@yx0716](https://github.com/yx0716) | 2025/4/8 | [5d62393](https://github.com/vllm-project/vllm-ascend/commit/5d6239306be9b0f5ac6dbaa137048c372a92ff20) |
| 32 | [@celestialli](https://github.com/celestialli) | 2025/4/7 | [2b765dc](https://github.com/vllm-project/vllm-ascend/commit/2b765dcc4974b1bafc26ff5da817ce7e652f0eb0) |
| 31 | [@hfadzxy](https://github.com/hfadzxy) | 2025/3/30 | [7beb433](https://github.com/vllm-project/vllm-ascend/commit/7beb4339dc8047af9ef64db1d0a8c59ddbb3709f) |
| 30 | [@wuhuikx](https://github.com/wuhuikx) | 2025/3/28 | [57a84bb](https://github.com/vllm-project/vllm-ascend/commit/57a84bb7befeaa0dc62aa35fa406e4d6affbfcca) |
| 29 | [@zzzzwwjj](https://github.com/zzzzwwjj) | 2025/3/28 | [12390af](https://github.com/vllm-project/vllm-ascend/commit/12390af075962456ecc8233d8dcce7064b75f390) |
| 28 | [@ganyi1996ppo](https://github.com/ganyi1996ppo) | 2025/3/28 | [27e86b9](https://github.com/vllm-project/vllm-ascend/commit/27e86b993a6a810d818143ec9dbfc439a419fa77) |
| 27 | [@ZhengZhenyu](https://github.com/ZhengZhenyu) | 2025/3/26 | [0b5a964](https://github.com/vllm-project/vllm-ascend/commit/0b5a9643fd6c3240d7ede669e37209d7ff433841) |
| 26 | [@baifanxxx](https://github.com/baifanxxx) | 2025/3/26 | [1225052](https://github.com/vllm-project/vllm-ascend/commit/122505208ff6284f409846ca7294f4a4b9883285) |
| 25 | [@rjg-lyh](https://github.com/rjg-lyh) | 2025/3/13 | [6512470](https://github.com/vllm-project/vllm-ascend/commit/65124705fb39d4cc2c94c80254421e067a82fe50) |
| 24 | [@xiemingda-1002](https://github.com/xiemingda-1002) | 2025/3/12 | [59ea23d](https://github.com/vllm-project/vllm-ascend/commit/59ea23d0d394879d7f33de6fd22242539b9c3cc5) |
| 23 | [@yiz-liu](https://github.com/yiz-liu) | 2025/3/11 | [0db6670](https://github.com/vllm-project/vllm-ascend/commit/0db6670bfab8cb1d84c9e7270df0a1d42d6ce7ca) |
| 22 | [@new-TonyWang](https://github.com/new-TonyWang) | 2025/3/11 | [dfb4e23](https://github.com/vllm-project/vllm-ascend/commit/dfb4e23e9d820ac992a071c123bbe983c7b01b2e) |
| 21 | [@mengwei805](https://github.com/mengwei805) | 2025/3/6 | [8fcf3d1](https://github.com/vllm-project/vllm-ascend/commit/8fcf3d1704084626db35c5dc82ade446508598d4) |
| 20 | [@baymax591](https://github.com/baymax591) | 2025/2/28 | [e8131b9](https://github.com/vllm-project/vllm-ascend/commit/e8131b99cf199f50a304e6e6fb125a1b95bcc92b) |
| 19 | [@dependabot](https://github.com/dependabot) | 2025/2/27 | [a5564ed](https://github.com/vllm-project/vllm-ascend/commit/a5564ed5d8fd9818936a22d9ea35951a27513b4c) |
| 18 | [@shink](https://github.com/shink) | 2025/2/27 | [6aed833](https://github.com/vllm-project/vllm-ascend/commit/6aed83335cbe92fd0b8ef07c28966a753d012ccb) |
| 17 | [@wwfu109](https://github.com/wwfu109) | 2025/2/27 | [b074047](https://github.com/vllm-project/vllm-ascend/commit/b07404766bdaf6e3cebc5cb0aba89a247501302e) |
| 16 | [@kunpengW-code](https://github.com/kunpengW-code) | 2025/2/26 | [ca807ce](https://github.com/vllm-project/vllm-ascend/commit/ca807ce49ed64aa89242f5ae29b9862a77648b45) |
| 15 | [@Yaphets24](https://github.com/Yaphets24) | 2025/2/22 | [d0b3cb4](https://github.com/vllm-project/vllm-ascend/commit/d0b3cb4fa79d5fc7f8245a3c68885ce1fa030ba4) |
| 14 | [@noemotiovon](https://github.com/noemotiovon) | 2025/2/21 | [202b39a](https://github.com/vllm-project/vllm-ascend/commit/202b39a38c2869b0ecc3df486550fb555a2eb0c0) |
| 13 | [@SidaoY](https://github.com/SidaoY) | 2025/2/18 | [718c763](https://github.com/vllm-project/vllm-ascend/commit/718c7638555d12cd43ea2a9e497e185778b68595) |
| 12 | [@ShiyaNiu](https://github.com/ShiyaNiu) | 2025/2/17 | [36ea38f](https://github.com/vllm-project/vllm-ascend/commit/36ea38fde56437ff1745bd95cd8d9e02a6578d38) |
| 11 | [@ji-huazhong](https://github.com/ji-huazhong) | 2025/2/12 | [c8b57d1](https://github.com/vllm-project/vllm-ascend/commit/c8b57d10b24efcd9b4fadeb66cfbf66aa3dd5f82) |
| 10 | [@Angazenn](https://github.com/Angazenn) | 2025/2/11 | [7637759](https://github.com/vllm-project/vllm-ascend/commit/7637759056028839c74960d9cfd3ce6275ee5d35) |
| 9 | [@whx-sjtu](https://github.com/whx-sjtu) | 2025/2/7 | [8fc5dc9](https://github.com/vllm-project/vllm-ascend/commit/8fc5dc966aaf4e174d1ec0d1902c40289411ec0e) |
| 8 | [@zouyida2002](https://github.com/zouyida2002) | 2025/2/7 | [4495fc6](https://github.com/vllm-project/vllm-ascend/commit/4495fc68389e3fb1ef14534c202948931e38446b) |
| 7 | [@hw_whx](https://github.com/hw_whx) | 2025/2/7 | [7d16772](https://github.com/vllm-project/vllm-ascend/commit/7d1677263bc6628ade33bb780455e0f6e5b9b27a) |
| 6 | [@MengqingCao](https://github.com/MengqingCao) | 2025/2/6 | [7d9ae22](https://github.com/vllm-project/vllm-ascend/commit/7d9ae22ecb6dc3ea4e720e5109cf46e1ae7da730) |
| 5 | [@Potabk](https://github.com/Potabk) | 2025/2/6 | [8cb5615](https://github.com/vllm-project/vllm-ascend/commit/8cb5615fb010b34c2f4f89e03e6257bfee851f86) |
| 4 | [@wangxiyuan](https://github.com/wangxiyuan) | 2025/2/6 | [a48b9ad](https://github.com/vllm-project/vllm-ascend/commit/a48b9addefd292af523644411d4ff4142dd4bc66) |
| 3 | [@shen-shanshan](https://github.com/shen-shanshan) | 2025/2/6 | [bfccf73](https://github.com/vllm-project/vllm-ascend/commit/bfccf739e2fe121b54d9b198c2ec205a9379190e) |
| 2 | [@Yikun](https://github.com/Yikun) | 2025/2/5 | [d5e7756](https://github.com/vllm-project/vllm-ascend/commit/d5e7756028bd5884ade96b654555c375770a2f64) |
| 1 | [@simon-mo](https://github.com/simon-mo) | 2025/1/29 | [eb28342](https://github.com/vllm-project/vllm-ascend/commit/eb283428ddc17207b6866118f9bc15454b5b8801) |
